print("import: 'tlz'")
import tlz

print("import: 'toolz'")
import toolz

print("import: 'toolz.curried'")
import toolz.curried

print("import: 'toolz.functoolz'")
import toolz.functoolz

print("import: 'toolz.sandbox'")
import toolz.sandbox

